# Pongy

Ping-pong multiplayer client-server game up to 4 players over network.

Tested on Mac OS and Windows.

## Requires

Python 3.10

## Install

```
$ pip install pongy
```

## Run Server

```
$ pongy -d
```

## Run Client

```
$ pongy -h <server-ip>
```

![UI screenshot](https://github.com/vyalovvldmr/pongy/blob/main/screen.png?raw=true)
